==> zio-aws-apprunner_2.13-5.17.162.2-sources.jar: zio/aws/apprunner/model/Runtime.scala <==
package zio.aws.apprunner.model
import scala.jdk.CollectionConverters._
sealed trait Runtime {
  def unwrap: software.amazon.awssdk.services.apprunner.model.Runtime
}
object Runtime {
  def wrap(
      value: software.amazon.awssdk.services.apprunner.model.Runtime
  ): zio.aws.apprunner.model.Runtime = value match {
    case software.amazon.awssdk.services.apprunner.model.Runtime.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.PYTHON_3 =>
      val r = PYTHON_3
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_12 =>
      val r = NODEJS_12
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_14 =>
      val r = NODEJS_14
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_8 =>
      val r = CORRETTO_8
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_11 =>
      val r = CORRETTO_11
      r
  }
  case object unknownToSdkVersion extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.UNKNOWN_TO_SDK_VERSION
  }
  case object PYTHON_3 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.PYTHON_3
  }
  case object NODEJS_12 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_12
  }
  case object NODEJS_14 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_14
  }
  case object CORRETTO_8 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_8
  }
  case object CORRETTO_11 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_11
  }
}

==> zio-aws-apprunner_2.13-5.17.295.9-sources.jar: zio/aws/apprunner/model/Runtime.scala <==
package zio.aws.apprunner.model
import scala.jdk.CollectionConverters._
sealed trait Runtime {
  def unwrap: software.amazon.awssdk.services.apprunner.model.Runtime
}
object Runtime {
  def wrap(
      value: software.amazon.awssdk.services.apprunner.model.Runtime
  ): zio.aws.apprunner.model.Runtime = value match {
    case software.amazon.awssdk.services.apprunner.model.Runtime.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.PYTHON_3 =>
      val r = PYTHON_3
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_12 =>
      val r = NODEJS_12
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_14 =>
      val r = NODEJS_14
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_8 =>
      val r = CORRETTO_8
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_11 =>
      val r = CORRETTO_11
      r
    case software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_16 =>
      val r = NODEJS_16
      r
  }
  case object unknownToSdkVersion extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.UNKNOWN_TO_SDK_VERSION
  }
  case object PYTHON_3 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.PYTHON_3
  }
  case object NODEJS_12 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_12
  }
  case object NODEJS_14 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_14
  }
  case object CORRETTO_8 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_8
  }
  case object CORRETTO_11 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.CORRETTO_11
  }
  case object NODEJS_16 extends zio.aws.apprunner.model.Runtime {
    override def unwrap
        : software.amazon.awssdk.services.apprunner.model.Runtime =
      software.amazon.awssdk.services.apprunner.model.Runtime.NODEJS_16
  }
}
